"use strict";

module.exports = function (_ref) {
  var t = _ref.types;

  var removeOrVoid = require("babel-helper-remove-or-void")(t);

  var visitor = {
    // Remove the call if it stands on it's own.
    ExpressionStatement: function ExpressionStatement(path) {
      var node = path.node;

      if (isEmptyFunction(node.expression)) {
        removeOrVoid(path);
      }
    },


    // If we're not in an expression statement we can't remove
    // the call.
    CallExpression: function CallExpression(path) {
      var node = path.node;

      if (isEmptyFunction(node)) {
        path.replaceWith(t.booleanLiteral(false));
      }
    }
  };

  return {
    name: "minify-empty-function",
    visitor: {
      // Unfortunately we have to do it in a seperate pass to ensure that
      // the expression statements are removed otherwise the calls may
      // end in conditionals or sequence expressions.
      Program: function Program(path) {
        path.traverse(visitor, {});
      }
    }
  };

  function isEmptyFunction(node) {
    return t.isCallExpression(node) && t.isIdentifier(node.callee, { name: "emptyFunction" });
  }
};